smc-lammps documentation
========================

`smc-lammps`_ is a python package that uses `LAMMPS`_ to perform coarse-grained Molecular Dynamics simulations of `SMC complexes`_.

For information about installation and usage, view the `README`_ on github.

.. _`smc-lammps`: https://github.com/LucasDooms/SMC_LAMMPS
.. _`README`: https://github.com/LucasDooms/SMC_LAMMPS#user-content-dna-loop-extrusion-by-smccs-in-lammps
.. _`LAMMPS`: https://docs.lammps.org
.. _`SMC complexes`: https://en.wikipedia.org/wiki/SMC_protein

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   smc_lammps
